import React from 'react';
import { render, fireEvent, screen } from '@testing-library/react';
import { Button } from './Button';

describe('Button component', () => {
  it('should render without crashing', () => {
    render(<Button>Click me</Button>);
  });

  it('should render children correctly', () => {
    render(<Button>Click me</Button>);
    expect(screen.getByText('Click me')).toBeInTheDocument();
  });

  it('should apply className prop correctly', () => {
    // arrange
    render(<Button className="test-class">Click me</Button>);
    const button = screen.getByRole('button');

    // assert
    expect(button).toHaveClass('test-class');
  });

  it('should render spinner when loading prop is true', () => {
    // arrange
    render(<Button loading>Click me</Button>);

    // assert
    const status = screen.getByTestId('loader');
    expect(status).toBeInTheDocument();
  });

  it('should disable button when disabled prop is true', () => {
    // arrange
    render(<Button disabled>Click me</Button>);
    const button = screen.getByRole('button');

    // assert
    expect(button).toBeDisabled();
  });

  it('should set type correctly', () => {
    // arrange
    render(<Button type="submit">Click me</Button>);
    const button = screen.getByRole('button');

    // assert
    expect(button).toHaveAttribute('type', 'submit');
  });

  it('should applies width correctly', () => {
    // arrange
    render(<Button width={100}>Click me</Button>);
    const button = screen.getByRole('button');

    // assert
    expect(button).toHaveStyle('width: 100px');
  });

  it('should call onClick callback when clicked', () => {
    // arrange
    const onClick = jest.fn();
    render(<Button onClick={onClick}>Click me</Button>);
    const button = screen.getByRole('button');

    // act
    fireEvent.click(button);

    // assert
    expect(onClick).toHaveBeenCalled();
  });
});
